Violation

Struct Violation 

pub struct Violation { /* private fields */ }
Represents Violation found during validation with detailed error message, error code and the constraint for which the validation failed Equivalence of Violation is not supported due to its tree structure of having children Violations. Please use macro assert_equivalent_violations!(violation1, violation2) for comparing if two violations are equal. This macro uses flattened_violations and does not depend on the order of the children Violations. For non-equivalent violations use macro assert_non_equivalent_violations!(violation1, violation2).

Implementations

Source

impl Violation

pub fn new<A: AsRef<str>, B: AsRef<str>>( constraint: A, code: ViolationCode, message: B, ion_path: &mut IonPath, ) -> Self

pub fn with_violations<A: AsRef<str>, B: AsRef<str>>( constraint: A, code: ViolationCode, message: B, ion_path: &mut IonPath, violations: Vec<Violation>, ) -> Self

pub fn ion_path(&self) -> &IonPath

pub fn message(&self) -> &String

pub fn code(&self) -> &ViolationCode

pub fn flattened_violations(&self) -> Vec<&Violation>

Provides flattened list of leaf violations which represent the root cause of the top-level violation.

pub fn violations(&self) -> impl Iterator<Item = &Violation>